@@ -35,7 +35,8 @@ function(dframe, expand = FALSE, drop.zero = FALSE, zero.pseudo="zero.pseudo")
         zpart <- NULL
 # expand argument
     if (expand) {
-        tmp <- data.frame(inflate(x[, c(1:2,4)], x[, 3]))
+#        tmp <- data.frame(inflate(x[, c(1:2,4)], x[, 3])) ## inflate is obsolete
+        tmp <- rep.data.frame(x[, c(1:2,4)], x[, 3])
         x <- data.frame(tmp[, 1:2], rep(1, sum(x[, 3])), tmp[, 3])}
 # check match with predefined characters
     if (!is.null(zpart)){
